@@ -3,7 +3,7 @@ import numpy as np
 try:
     import tensorflow as tf
 except ImportError:
-    raise ImportError("Please install the following packages: torch.")
+    raise ImportError("Please install the following packages: tensorflow.")
 
 from maskay.module import MaskayModule
 
@@ -38,4 +38,4 @@ class Module(MaskayModule):
                 tensor = np.moveaxis(self.forward(tensor).numpy(), 3, 1)
         else:
             raise ValueError("Unknown device: " + str(self.device))
-        return tensor
\ No newline at end of file
+        return tensor
